﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class GameController : MonoBehaviour {

    public Transform sewerGrate;
    public Transform wackyMan;
    public Transform water;
    public ParticleSystem sewerBlast;
    private ScoreController scoreController;
    private bool started = false;
    public Text timerText;
    public Text highScoreText;
    public float waveYPlane = 1f;
    public Text manholeText;
    private string collectedManhole;

    private float timer = 120f;

	void Start () {
        StartCoroutine(startUp());
        scoreController = GetComponent<ScoreController>();
        timerText.text = "READY";
        manholeText.text = "";
        highScoreText.text = "" + loadHighScore();
	}
	
	void Update () {
		if(started)
        {
            string minutes = Mathf.Floor(timer / 60).ToString("0");
            string seconds = Mathf.Floor(timer % 60).ToString("00");

            timer -= Time.deltaTime;
            timerText.text = minutes + ":" + seconds;

            if(timer <= 0)
            {
                endGame();
            }
        }

        if(Input.GetKey(KeyCode.Escape))
        {
            Application.LoadLevel("Start");
        }
	}

    private IEnumerator startUp()
    {
        sewerBlast.transform.position = sewerGrate.position;
        water.transform.position = new Vector3(0f, waveYPlane - 10f, 0f);
        yield return new WaitForSeconds(2f);
        timerText.text = "SURF'S UP!";
        sewerBlast.Play();
        sewerBlast.GetComponent<AudioSource>().Play();
        sewerGrate.GetComponent<Rigidbody>().AddForce(Vector3.up * 1000f, ForceMode.Acceleration);
        while(water.transform.position.y < waveYPlane)
        {
            water.transform.Translate(Vector3.up * Time.deltaTime * 5f);
            yield return null;
        } 
        sewerBlast.Stop();
        timerText.text = "2:00";
        yield return new WaitForSeconds(1f);
        started = true;
        yield return null;
    }

    public bool hasStarted()
    {
        return started;
    }

    private int loadHighScore()
    {
        return PlayerPrefs.GetInt("HS" + Application.loadedLevelName, 0);
    }

    private void saveHighScore()
    {
        int oldScore = loadHighScore();
        if(scoreController.getScore() > oldScore)
        {
            PlayerPrefs.SetInt("HS" + Application.loadedLevelName, scoreController.getScore());
            PlayerPrefs.Save();
        }
    }

    private void endGame()
    {
        saveHighScore();
        started = false;
        StartCoroutine(endOfGame());
        
    }

    public void collectLetter(string letter)
    {
        collectedManhole += letter;

        string displayManhole = "";
        if(collectedManhole.Contains("m"))
            displayManhole += "m";
        if (collectedManhole.Contains("a"))
            displayManhole += "a";
        if (collectedManhole.Contains("n"))
            displayManhole += "n";
        if (collectedManhole.Contains("h"))
            displayManhole += "h";
        if (collectedManhole.Contains("o"))
            displayManhole += "o";
        if (collectedManhole.Contains("l"))
            displayManhole += "l";
        if (collectedManhole.Contains("e"))
            displayManhole += "e";

        if(displayManhole.Equals("manhole"))
        {
            onCollectedManhole();
        }

        manholeText.text = displayManhole.ToUpper();
    }

    private void onCollectedManhole()
    {
        scoreController.addScoreDirect(10000);
    }

    private IEnumerator endOfGame()
    {
        yield return new WaitForSeconds(1f);
        timerText.text = "TIME UP!";

        yield return new WaitForSeconds(5f);

        Application.LoadLevel("Start");
    }
}
