﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class ScoreController : MonoBehaviour
{
    public Transform sewerGrate;
    public Waves waves;
    private float airTime = 0f;
    private int score = 0;
    private float combo = 1f;
    public Text scoringText;
    public Text scoringScoreText;
    public Text scoreText;
    private GameController gameController;
    private List<Trick> trickList;
    private float timeSinceLastTrick = 0;
    public Transform manHead;
    public Transform manBody;
    private float startRotation = 0;
    private float lastRotation = 0;
    private WackyManAudio audio;

    void Start()
    {
        scoringText.text = "";
        scoreText.text = "0";
        scoringScoreText.text = "";
        gameController = GetComponent<GameController>();
        trickList = new List<Trick>();
        audio = GameObject.FindObjectOfType<WackyManAudio>();
    }

    void Update()
    {
        if (gameController.hasStarted())
        {
            if (!waves.inWaves(sewerGrate))
            {
                airTime += Time.deltaTime * 200f;
                float bankedScore = airTime;
                if(airTime < 50f)
                {
                    startRotation = 0;
                    lastRotation = manBody.rotation.eulerAngles.y;
                }
                if (airTime >= 100f)
                {
                    timeSinceLastTrick = 0;
                    float angle = manBody.rotation.eulerAngles.y - lastRotation;
                    if (angle > 180) angle -= 360;
                    if (angle < -180) angle += 360;
                    startRotation += Mathf.Abs(angle);
                    lastRotation = manBody.rotation.eulerAngles.y;
                    float displayRotation = Mathf.Floor(startRotation / 180) * 180;
                    string tricknames;
                    if(displayRotation > 0)
                        tricknames = displayRotation + " AIR";
                    else
                        tricknames = "AIR";
                    combo = 1;
                    for(int i = 0; i < trickList.Count; i++)
                    {
                        if(trickList[i].score > 100f)
                        {
                            combo++;
                            tricknames += " + " + trickList[i].name;
                            bankedScore += trickList[i].score;
                        }
                    }
                    scoringText.text = tricknames;
                    if(combo < 2)
                        scoringScoreText.text = "" + Mathf.RoundToInt(bankedScore);
                    else
                        scoringScoreText.text = "" + Mathf.RoundToInt(bankedScore) + " x " + combo;
                }
            }
            else
            {
                if (airTime > 100f)
                {
                    addScore(Mathf.RoundToInt(airTime));

                }
                airTime = 0f;
                //scoringText.text = "";
                timeSinceLastTrick += Time.deltaTime;
                if(timeSinceLastTrick > 2f)
                {
                    scoringText.text = "";
                    scoringScoreText.text = "";
                    trickList.Clear();
                }
                //scoringScoreText.text = "";
            }
        }
    }

    public int getScore()
    {
        return score;
    }

    public void addScore(int amount)
    {
        int scoreAdded = 0;
        bool sloppy = false;
        if(manHead.position.y < sewerGrate.position.y)
        {
            sloppy = true;
        }
        scoreAdded += Mathf.RoundToInt(amount);
        for (int i = 0; i < trickList.Count; i++)
        {
            if(!trickList[i].ended)
            {
                sloppy = true;
            }
            if (trickList[i].score > 100f)
            {
                scoreAdded += Mathf.RoundToInt(trickList[i].score);
            }
        }
        int angleScore = Mathf.FloorToInt(startRotation / 180) * 180;
        scoreAdded += angleScore;
        
        if(sloppy)
        {
            scoringText.text = "SLOPPY " + scoringText.text;
            combo = 1;
        }
        else
        {
            string congrats = "";
            if(scoreAdded < 1000)
            {
                congrats = "GOOD";
            }
            else if (scoreAdded < 5000)
            {
                congrats = "AWESOME";
            }
            else if (scoreAdded < 10000)
            {
                congrats = "GNARLY";
            }
            else if (scoreAdded < 25000)
            {
                congrats = "RADICAL";
            }
            else
            {
                congrats = "TUBULAR";
            }
            scoringText.text = congrats + " " + scoringText.text;
        }
        scoreAdded *= (int)combo;
        scoringScoreText.text = "" + scoreAdded; 
        combo = 1;
        score += scoreAdded;
        scoreText.text = "" + score;
        trickList.Clear();
    }

    public void addScoreDirect(int amount)
    {
        score += amount;
        scoreText.text = "" + score;
    }

    public void newTrick(Trick trick)
    {
        for (int i = 0; i < trickList.Count; i++)
        {
            if(trick.trickNum==1 && trickList[i].trickNum==2 && !trickList[i].ended)
            {
                trick.name = "ROCKET AIR";
            } else if (trick.trickNum == 2 && trickList[i].trickNum == 1 && !trickList[i].ended)
            {
                trick.name = "ROCKET AIR";
            }
        }
        trickList.Add(trick);
        audio.playTrickSFX();
    }

    public void updateTrick(Trick trick)
    {
        trick.score += Mathf.RoundToInt(Time.deltaTime * 500f);
    }

    public void endTrick(Trick trick)
    {
        //trickList.Remove(trick);
        trick.ended = true;
    }
}

public class Trick 
{
    public int trickNum;
    public string name;
    public int score;
    public string modifier;
    public bool ended = false;
}





