﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class StartScreen : MonoBehaviour {

    public string nextLevel;
    public Transform logo;
    public RectTransform menu;
    public RectTransform credits;
    public RectTransform animations;
    public Text textBoxText;
    public RectTransform textBox;
    public RectTransform waveFront;
    public RectTransform waveMid;
    public RectTransform waveBack;
    public RectTransform dude;
    private AudioSource audio;

    private bool canSkip = false;

	void Start () {
        logo.localScale = Vector3.zero;
        menu.localScale = Vector3.zero;
        credits.localScale = Vector3.zero;
        animations.localScale = Vector3.zero;
        StartCoroutine(StartUp());
        audio = GetComponent<AudioSource>();
	}
	

	void Update () {
		if(Input.GetButtonDown("Jump") || Input.GetMouseButtonDown(0))
        {
            if(canSkip)
                Application.LoadLevel(nextLevel);
        }

        if(canSkip)
        {
            waveBack.Translate(Vector3.up * Mathf.Sin(1 + Time.time)/8f);
            waveMid.Translate(Vector3.up * Mathf.Sin(2 + Time.time)/8f);
            waveFront.Translate(Vector3.up * Mathf.Sin(3 + Time.time)/8f);
            dude.Translate(Vector3.up * Mathf.Sin(4 + Time.time)/8f);
        }
	}

    public void OnStartClicked()
    {
        StartCoroutine(DoStartingStuff());
    }

    public void OnCreditsClicked()
    {
        ShowCredits();
    }

    public void OnExitClicked()
    {
        Application.Quit();
    }

    private void ShowCredits()
    {
        credits.localScale = Vector3.one * 1f;
        menu.localScale = Vector3.one * 0f;
    }

    private void HideCredits()
    {
        credits.localScale = Vector3.one * 0f;
        menu.localScale = Vector3.one * 1f;
    }

    private void HideMenu()
    {
        menu.localScale = Vector3.one * 0f;
    }

    public void OnCreditsBackClicked()
    {
        HideCredits();
    }

    private IEnumerator StartUp()
    {
        logo.localScale = Vector3.one * 10f;
        while(logo.localScale.x > 1f)
        {
            logo.localScale -= Vector3.one * Time.deltaTime * 10f;
            yield return null;
        }

        Vector3 menuStart = menu.position;
        menu.localScale = Vector3.one;
        menu.Translate(Vector3.left * 200f);
        
        while (menu.position.x < menuStart.x)
        {
            menu.Translate(Vector3.right * Time.deltaTime * 400f);
            yield return null;
        }
    }

    private IEnumerator DoStartingStuff()
    {
        
        HideMenu();

        float waitTime = 2f;
        float textTime = 0.04f;

        animations.localScale = Vector3.one;
        waveBack.Translate(Vector3.left * 2500f);
        waveMid.Translate(Vector3.left * 2500f);
        waveFront.Translate(Vector3.left * 2500f);
        dude.Translate(Vector3.left * 2000f);

        string targetText = "";

        Vector3 textBoxPos = textBox.position;
        textBox.Translate(Vector3.down * 400f);
        //text box come in
        while (textBox.position.y < textBoxPos.y)
        {
            textBox.Translate(Vector3.up * 400f * Time.deltaTime);
            yield return null;
        }
        canSkip = true;

        targetText = "The year is 2017, and four years of rail construction have taken their toll on the streets of Canada's capital.";
        textBoxText.text = "";
        while (!textBoxText.text.Equals(targetText))
        {
            textBoxText.text += targetText.ToCharArray()[textBoxText.text.Length];
            if(textBoxText.text.Length % 2 == 0)
                audio.Play();
            yield return new WaitForSeconds(textTime);
        }

        yield return new WaitForSeconds(waitTime);
        targetText = "Once again, a massive sinkhole has appeared in the city's downtown core, to devastating effect.";
        textBoxText.text = "";
        while (!textBoxText.text.Equals(targetText))
        {
            textBoxText.text += targetText.ToCharArray()[textBoxText.text.Length];
            if (textBoxText.text.Length % 2 == 0)
                audio.Play();
            yield return new WaitForSeconds(textTime);
        }

        yield return new WaitForSeconds(waitTime);
        targetText = "Water mains have collapsed and forced manhole covers to burst free, flooding the streets and drowning pedestrians.";
        textBoxText.text = "";
        while (!textBoxText.text.Equals(targetText))
        {
            textBoxText.text += targetText.ToCharArray()[textBoxText.text.Length];
            if (textBoxText.text.Length % 2 == 0)
                audio.Play();
            yield return new WaitForSeconds(textTime);
        }

        //third line finishes, waves come in
        float distance = 0;
        while(distance < 2500f)
        {
            distance += Time.deltaTime * 400f;
            waveBack.Translate(Vector3.right * Time.deltaTime * 400f);
            waveMid.Translate(Vector3.right * Time.deltaTime * 400f);
            waveFront.Translate(Vector3.right * Time.deltaTime * 400f);
            yield return 0f;
        }

        targetText = "Few have survived, and while the manholes remain open, there is no chance of recovery.";
        textBoxText.text = "";
        while (!textBoxText.text.Equals(targetText))
        {
            textBoxText.text += targetText.ToCharArray()[textBoxText.text.Length];
            if (textBoxText.text.Length % 2 == 0)
                audio.Play();
            yield return new WaitForSeconds(textTime);
        }

        yield return new WaitForSeconds(waitTime);
        targetText = "Now, with rescue efforts thwarted by massive waves and gale-force winds, there is only one hope for the city...";
        textBoxText.text = "";
        while (!textBoxText.text.Equals(targetText))
        {
            textBoxText.text += targetText.ToCharArray()[textBoxText.text.Length];
            if (textBoxText.text.Length % 2 == 0)
                audio.Play();
            yield return new WaitForSeconds(textTime);
        }

        //Dude slides in
        distance = 0f;
        while(distance < 2000f)
        {
            distance += 400f * Time.deltaTime;
            dude.Translate(Vector3.right * 400f * Time.deltaTime);
            yield return null;
        }

        targetText = "An entity of radical and unknown origins takes to the watery streets, powered by air and awesomeness to thwart danger and ride the waves!";
        textBoxText.text = "";
        while (!textBoxText.text.Equals(targetText))
        {
            textBoxText.text += targetText.ToCharArray()[textBoxText.text.Length];
            if (textBoxText.text.Length % 2 == 0)
                audio.Play();
            yield return new WaitForSeconds(textTime);
        }

        //dude fly away
        while (dude.position.x < 2000f)
        {
            dude.Translate(Vector3.right * 400f * Time.deltaTime);
            yield return null;
        }

        Application.LoadLevel(nextLevel);

        yield return 0;
    }
}
